@@ -1,10 +1,10 @@
 #' Break a matrix into blocks
 #'
 #' @example examples/findBlocks.R
-#' @nord
 #'
 #' @param M \code{matrix} or \code{editmatrix} that will be broken in blocks
 #' @return list with seperate matrix blocks
+#' @export
 findBlocks <- function(M){
    
    block <- function(B){
@@ -22,8 +22,12 @@ findBlocks <- function(M){
      b
    }
    
-   
-   m <- as.matrix(M)
+   if (is.editmatrix(M)){
+      m <- getA(M)
+   }
+   else {
+      m <- as.matrix(M)
+   }
    
    D <- m != 0
    
@@ -57,4 +61,4 @@ findBlocks <- function(M){
               removeEmpty(M[b,,drop=FALSE])
            }
          )
-}
\ No newline at end of file
+}
